@@ -2,12 +2,12 @@
 #'
 #' \code{detect_sdg} identifies SDGs in text using SDG query systems developed by the Aurora Universities Network, SIRIS Academic, and Elsevier.
 #'
-#' \code{detect_sdg} implements three SDG query systems developed by the Arora Universities Network (see \code{\link{aurora_queries}}), SIRIS Academic (see \code{\link{siris_queries}}), and Elsevier (see \code{\link{elsevier_queries}}), and one keyword-based system by Bautista-Puig and Mauleón labeled Ontology (see \code{\link{ontology_queries}}). `detect_sdg` calls dedicated \code{detect_*} for each of the four system. Search of the Lucene-style Boolean queries and the keywords is implemented using the \code{\link[corpustools]{search_features}} function from the \href{https://cran.r-project.org/package=corpustools}{\code{corpustools}} package.
+#' \code{detect_sdg} implements five SDG query systems. Three systems developed by the Aurora Universities Network (see \code{\link{aurora_queries}}), SIRIS Academic (see \code{\link{siris_queries}}), and Elsevier (see \code{\link{elsevier_queries}}) rely on Lucene-style Boolean queries, whereas two query systems developed by OSDG (see \code{\link{osdg_queries}}) and SDSN (see \code{\link{sdsn_queries}}) rely on basic keyword matching. `detect_sdg` calls dedicated \code{detect_*} for each of the five system. Search of the queries is implemented using the \code{\link[corpustools]{search_features}} function from the \href{https://cran.r-project.org/package=corpustools}{\code{corpustools}} package.
 #'
-#' By default, \code{detect_sdg} runs only the three query systems, as they are considerably less liberal than the keyword-based Ontology and therefore likely produce more valid SDG classifications. Users should be aware that systematic validations and comparison between the systems are still largely lacking. Consequently, any results should be interpreted with a high level caution.
+#' By default, \code{detect_sdg} runs only the Aurora, SIRIS, and Elsevier query systems, as they are considerably less liberal than the SDSN and OSDG systems and therefore likely produce more valid SDG classifications. Users should be aware that systematic validations and comparison between the systems are largely lacking and that results should be interpreted with caution.
 #'
 #' @param text \code{character} vector or object of class \code{tCorpus} containing text in which SDGs shall be detected.
-#' @param systems \code{character} vector specifying the query systems to be used. Can be one or more of \code{"aurora"}, \code{"siris"}, \code{"elsevier"}, \code{"sdsn"}, and \code{"ontology"}. By default all but \code{"sdsn"} and \code{"ontology"} are used.
+#' @param systems \code{character} vector specifying the query systems to be used. Can be one or more of \code{"Aurora"}, \code{"SIRIS"}, \code{"Elsevier"}, \code{"SDSN"}, and \code{"OSDG"}. By default all systems except \code{"OSDG"} and \code{"SDSN"} are used.
 #' @param sdgs \code{numeric} vector with integers between 1 and 17 specifying the sdgs to identify in \code{text}. Defaults to \code{1:17}.
 #' @param output \code{character} specifying the level of detail in the output. The default \code{"features"} returns a \code{tibble} with one row per matched query, include a variable containing the features of the query that were matched in the text. By contrast, \code{"documents"} returns an aggregated \code{tibble} with one row per matched sdg, without information on the features.
 #' @param verbose \code{logical} specifying whether messages on the function's progress should be printed.
@@ -27,15 +27,19 @@
 #' # run sdg detection
 #' hits <- detect_sdg(projects)
 #'
-#' # run sdg detection with aurora only
-#' hits <- detect_sdg(projects, systems = "aurora")
+#' # run sdg detection with Aurora only
+#' hits <- detect_sdg(projects, systems = "Aurora")
 #'
 #' # run sdg detection for sdg 3 only
 #' hits <- detect_sdg(projects, sdgs = 3)
 #' }
 #' @export
 
-detect_sdg = function(text, systems = c("aurora","siris","elsevier"), sdgs = 1:17, output = c("features","documents"), verbose = TRUE){
+detect_sdg = function(text,
+                      systems = c("Aurora", "Elsevier", "SIRIS"),
+                      sdgs = 1:17,
+                      output = c("features","documents"),
+                      verbose = TRUE){
 
   # make corpus
   if(class(text)[1] == "character"){
@@ -54,24 +58,24 @@ detect_sdg = function(text, systems = c("aurora","siris","elsevier"), sdgs = 1:1
   sdgs = paste0("SDG-", ifelse(sdgs < 10, "0", ""),sdgs) %>% sort()
 
   # run sdg
-  if (!all(systems %in% c("aurora","elsevier","siris", "ontology", "sdsn"))){
-    stop("Argument system must be aurora, elsevier, siris or ontology.")
+  if (!all(systems %in% c("Aurora", "Elsevier", "SIRIS", "SDSN", "OSDG"))){
+    stop("Argument systems must be Aurora, Elsevier, SIRIS, SDSN, or OSDG.")
     }
-  if("aurora" %in% systems){
-    if(verbose) cat("\nRunning aurora queries",sep = '')
-    hits[["aurora"]] = detect_aurora(corpus, sdgs)}
-  if("siris" %in% systems) {
-    if(verbose) cat("\nRunning siris queries",sep = '')
-    hits[["siris"]] = detect_siris(corpus, sdgs)}
-  if("elsevier" %in% systems){
-    if(verbose) cat("\nRunning elsevier queries",sep = '')
-    hits[["elsevier"]] = detect_elsevier(corpus, sdgs)}
-  if("ontology" %in% systems) {
-    if(verbose) cat("\nRunning ontology queries",sep = '')
-    hits[["ontology"]] = detect_ontology(corpus, sdgs)}
-  if("sdsn" %in% systems) {
-    if(verbose) cat("\nRunning sdsn queries",sep = '')
-    hits[["sdsn"]] = detect_sdsn(corpus, sdgs)}
+  if("Aurora" %in% systems){
+    if(verbose) cat("\nRunning Aurora",sep = '')
+    hits[["Aurora"]] = detect_aurora(corpus, sdgs)}
+  if("SIRIS" %in% systems) {
+    if(verbose) cat("\nRunning SIRIS",sep = '')
+    hits[["SIRIS"]] = detect_siris(corpus, sdgs)}
+  if("Elsevier" %in% systems){
+    if(verbose) cat("\nRunning Elsevier",sep = '')
+    hits[["Elsevier"]] = detect_elsevier(corpus, sdgs)}
+  if("SDSN" %in% systems) {
+    if(verbose) cat("\nRunning SDSN",sep = '')
+    hits[["SDSN"]] = detect_sdsn(corpus, sdgs)}
+  if("OSDG" %in% systems) {
+    if(verbose) cat("\nRunning OSDG",sep = '')
+    hits[["OSDG"]] = detect_osdg(corpus, sdgs)}
 
   #combine lists to df
   hits <- do.call(rbind, hits)
